@@ -44,17 +44,17 @@ def get_plot_params(plot_params, show_score_diffs, diff):
         "serif": False,
         "show_score_diffs": show_score_diffs,
         "show_total": True,
-        "system_names": ["Sys. 1", "Sys. 2"],
+        "system_names": ["Text 1", "Text 2"],
         "tick_format": "{:.1f}",
         "tight": True,
         "title_fontsize": 18,
         "width": 7,
         "width_scaling": 1.2,
-        "xlabel": r"Per type average score shift $\delta s_{avg,r}$ (%)",
+        "xlabel": r"Score shift $\delta \Phi_{\tau}$ (%)",
         "xlabel_fontsize": 20,
         "xtick_fontsize": 14,
         "y_margin": 0.005,
-        "ylabel": r"Type rank $r$",
+        "ylabel": r"Rank",
         "ylabel_fontsize": 20,
         "ytick_fontsize": 14,
     }
