@@ -77,6 +77,7 @@ class Shift:
             self.type2score_1 = self.type2score_2
             self.show_score_diffs = False
         else:
+            lex_ref = None
             self.type2score_1 = {t: 1 for t in type2freq_1}
             self.type2score_2 = {t: 1 for t in type2freq_2}
             self.show_score_diffs = False
@@ -223,7 +224,10 @@ class Shift:
         # Normalize the total shift scores
         total_diff = sum(type2shift_score.values())
         self.diff = total_diff
-        if self.normalization == "variation":
+        if total_diff == 0:
+            warnings.warn("Score normalization is not well-defined because the total score diff is 0. Setting norm to 1")
+            self.norm = 1
+        elif self.normalization == "variation":
             abs_sum = sum(abs(s) for s in type2shift_score.values())
             self.norm = abs_sum
         elif self.normalization == "trajectory" and total_diff != 0:
